Ocyan plugin Sentry logging
===========================

About Sentry logging
--------------------
Sentry logging

Installation
------------
Add `ocyan.plugin.sentry_logging` to your projects dependencies.
